@@ -31,6 +31,7 @@ data <- matrix(c(1, 1, 0, 0, 1, 1,
                  0, 0, 1, 0, 1, 0,
                  0, 0, 1, 0, 0, 0,
                  0, 0, 1, 0, 0, 0), byrow = TRUE, ncol = 6)
+colnames(data) <- c("a", "b", "c", "d", "e", "f")
 dataSize <- dim(data)[1]
 node <- dim(data)[2]
 ivn <- vector("list", length = dataSize)
@@ -38,11 +39,13 @@ ivn_obs <- lapply(ivn, function(x){return(as.integer(0))})
 ivn_int <- lapply(1:dataSize, function(x){return(as.integer(x/6))})
 databn_obs <- sparsebnUtils::sparsebnData(data, ivn = ivn_obs, type = "discrete")
 databn_int <- sparsebnUtils::sparsebnData(data, ivn = ivn_int, type = "discrete")
+black_list = matrix(c("c", "a", "a", "b", "c", "d"), byrow = TRUE, ncol = 2)
+white_list = matrix(c("a", "e", "a", "d"), byrow = TRUE, ncol = 2)
 
 # test
 test_that("Testing cd_adaptive_run with adaptive option", {
   weights <- matrix(1, nrow=node, ncol=node)
-  final <- cd_adaptive_run(databn_obs, eor = NULL, weights=weights, lambda_seq=NULL, fmlam = 0.01, nlam = 10, eps=0.0001, convLb=0.02, qtol = 0.00001, gamma=1, upperbound=100.0, threshold = 10, permute = TRUE, adaptive = TRUE)
+  final <- cd_adaptive_run(databn_obs, eor = NULL, weights=weights, lambda_seq=NULL, fmlam = 0.01, nlam = 10, blacklist = NULL, whitelist = NULL, eps=0.0001, convLb=0.02, qtol = 0.00001, gamma=1, upperbound=100.0, threshold = 10, permute = TRUE, adaptive = TRUE)
 
   ### check output type
   expect_is(final, "list")
@@ -63,7 +66,7 @@ test_that("Testing cd_adaptive_run with adaptive option", {
 
 test_that("Testing cd_adaptive_run with none adaptive option", {
   weights <- matrix(1, nrow=node, ncol=node)
-  final <- cd_adaptive_run(databn_obs, eor = NULL, weights=weights, lambda_seq=NULL, fmlam = 0.01, nlam = 10, eps=0.0001, convLb=0.02, qtol = 0.00001, gamma=1, upperbound=100.0, threshold = 10, permute = TRUE, adaptive = FALSE)
+  final <- cd_adaptive_run(databn_obs, eor = NULL, weights=weights, lambda_seq=NULL, fmlam = 0.01, nlam = 10, blacklist = NULL, whitelist = NULL, eps=0.0001, convLb=0.02, qtol = 0.00001, gamma=1, upperbound=100.0, threshold = 10, permute = TRUE, adaptive = FALSE)
 
   ### check output type
   expect_is(final, "list")
